% Format pour les articles du congrés EDSYS
% License LGPL 3

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{edsys-congress}[2010/02/02 The EDSYS congress class for articles]

\typeout{}
\typeout{######################}
\typeout{}
\typeout{Format pour les articles du congrs EDSYS.}
\typeout{Mis  jour par Simon Vernhes (DCSD/ONERA) -- Nov. 2012}
\typeout{Mis  jour par Vikas SHUKLA (ISI/LAAS) -- Oct. 2012}
\typeout{Ecrit par Caroline Carvalho (DCSD/ONERA) -- fev. 2010}
\typeout{D'apres le format des JdT par Cedric Mauclair (DTIM/ONERA) -- sept. 2009}
\typeout{}
\typeout{######################}
\typeout{}


% Use the firs three macros to set the variables.
% This can be overriden in the document.
\def\congressnumber{\def\@congressnumber}
\def\congressyear{\def\@congressyear}
\def\congressdate{\def\@congressdate}
\def\congressplace{\def\@congressplace}

\congressnumber{14}
\congressyear{2013}
\congressdate{16 Avril}
\congressplace{Tarbes}

% Give the rest to the 'article' class
\DeclareOption*{
  \PassOptionsToClass{\CurrentOption}{article}
}

% \ExecuteOptions{francais}

\ProcessOptions\relax

\LoadClass[twoside,10pt]{article}
\RequirePackage[a4paper,top=0.9in,right=0.9in,bottom=0.9in,left=0.9in,nohead]{geometry}
\RequirePackage{babel}
\RequirePackage[runin]{abstract}
\RequirePackage{ifthen}
\RequirePackage{multicol}
\RequirePackage{float}
\RequirePackage{lmodern}
\RequirePackage{url}
\RequirePackage{graphicx}
\RequirePackage{calc}

\RequirePackage{amsmath}
\RequirePackage{amssymb}
\RequirePackage{amsthm}

\iflanguage{french}{\frenchspacing}{}
\flushbottom

% Colums separation
\def\@ColSep{18pt}
\setlength{\columnsep}{\@ColSep}

% Emphasis
\DeclareRobustCommand\em
  {\@nomath\em \ifdim \fontdimen\@ne\font >\z@
  \upshape \else \slshape \fi}

% Title
\def\@lab{}
\newcommand\lab[1]{\def\@lab{#1}}
\def\@univ{}
\newcommand\univ[1]{\def\@univ{#1}}
\def\@email{}
\newcommand\email[1]{\def\@email{#1}}
\def\@supervisor{}
\newcommand\supervisor[1]{\def\@supervisor{#1}}

\def\@maketitle
{
  \parindent \z@
  \begin{minipage}{0.5\textwidth}
    \includegraphics[width=35mm]{Logo-EDSYS.pdf}
  \end{minipage}
  \begin{minipage}{0.49\textwidth}
    \begin{flushright}
      \textbf{Congr\`es des Doctorants \@congressyear}\\
      EDSYS (\'Ecole Doctorale Syst\`emes)\\
      \@congressdate, \@congressplace
    \end{flushright}
  \end{minipage}
  \vskip 1mm
  \hrule height 1pt
  \vskip 3mm
  \begin{center}
  {\LARGE\bfseries\@title}
  \end{center}
  %\vskip 3mm
  {\large\bfseries\@author}
  \ifx \@email \@empty \else
    ({\ttfamily\@email\unskip})
  \fi
  \\[0.02in]
  \ifx \@lab \@empty \else
     {\large\@lab \\[0.02in]}
  \fi
  \ifx \@univ \@empty \else
     {\large \@univ \vskip 1mm}
  \fi
  \ifx \@supervisor \@empty \else
    \iflanguage{french}{Th\`ese encadr\'ee par :}{Thesis supervised by:}{}
    \@supervisor
    %\medskip
    \vskip 1mm
  \fi
  \hrule height 1pt
  \vskip 3mm
}

% Abstract
\renewenvironment{abstract}{
  \quotation\noindent
  {\normalfont\bfseries\abstractname\quad}
  \em
}
%{\endquotation
%\medskip
%\thispagestyle{empty}}

% Colums for the contents
\newenvironment{content}{
  \begin{multicols}{2}
  }
  {
  \end{multicols}
}

% Sections
\renewcommand\thesection{\Alph{section}.}
\renewcommand\section{
  \if@noskipsec \leavevmode \fi
  \par
  \addvspace{2ex}
  \@afterindentfalse
  \secdef\Section\sSection}
\def\Section[#1]#2{
  \refstepcounter{section}
  {\parindent \z@ \raggedright
    \interlinepenalty \@M
    \vbox{
      \normalfont \scshape
      \vglue\medskipamount
      \thesection\quad
      #2
      \vglue\smallskipamount
      \hrule
      }
    \par}
  \vskip 0.5ex
  }
\def\sSection#1{
  {\parindent \z@ \raggedright
    \interlinepenalty \@M
    \vbox{
      \normalfont \scshape
      #1
      \vglue\smallskipamount
      \hrule
      }
    \par}
  \vskip 0.5ex
  }

\renewcommand\thesubsection{\thesection\arabic{subsection}.}
\renewcommand\subsection{\@startsection{subsection}{2}{\z@}%
                                       {-\medskipamount}%
                                       {\medskipamount}%
                                       {\normalsize\itshape\raggedright}}


\renewcommand\subsubsection[1]{\paragraph{#1}}
\setcounter{secnumdepth}{2}

% Bibliography
\bibliographystyle{plain}

\renewenvironment{thebibliography}[1]
{
  \smallskip
  \section*{\refname}
  \hrule height 1pt
  \vglue\medskipamount
  \vspace{-0.5cm}
  \scriptsize
  \@mkboth{\MakeUppercase\refname}{\MakeUppercase\refname}
  \list{\@biblabel{\@arabic\c@enumiv}}
  {\settowidth\labelwidth{\@biblabel{#1}}
    \leftmargin\labelwidth
    \advance\leftmargin\labelsep
    \@openbib@code
    \usecounter{enumiv}
    \let\p@enumiv\@empty
    \renewcommand\theenumiv{\@arabic\c@enumiv}}
  \sloppy
  \clubpenalty4000
  \@clubpenalty \clubpenalty
  \widowpenalty4000
  \sfcode`\.\@m\small
  \setlength{\columnsep}{\labelwidth+\labelsep+\@ColSep}
  \begin{multicols}{2}
}
{\end{multicols}
  \def\@noitemerr
  {\@latex@warning{Empty `thebibliography' environment}}
  \endlist
}

% Footnotes
\addtolength{\skip\footins}{3mm plus 1mm}
\renewcommand\footnoterule{\vspace*{-3pt} \hrule width 1.5in height 0.4pt \vspace*{2.6pt}}

% Captions
\renewcommand{\fnum@figure}{\small{Figure~\thefigure}}
\renewcommand{\fnum@table}{\small{\iflanguage{french}{Tableau}{Table}~\thetable}}
